"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Caixa = void 0;
var path = __importStar(require("path"));
var string_utils_1 = require("../../utils/string-utils");
var codigo_de_barras_builder_1 = require("../codigo-de-barras-builder");
var gerador_de_digito_padrao_1 = require("../gerador-de-digito-padrao");
var pad = string_utils_1.StringUtils.pad;
var insert = string_utils_1.StringUtils.insert;
var NUMERO_CAIXA = '104';
var DIGITO_CAIXA = '0';
var Caixa = /** @class */ (function () {
    function Caixa() {
    }
    Caixa.prototype.getTitulos = function () {
        return {
            instrucoes: 'Instruções (texto de responsabilidade do beneficiário)',
            nomeDoPagador: 'Nome do Pagador',
            especie: 'Espécie Moeda',
            quantidade: 'Quantidade Moeda',
            valor: 'xValor'
        };
    };
    Caixa.prototype.exibirReciboDoPagadorCompleto = function () {
        return true;
    };
    Caixa.prototype.exibirCampoCip = function () {
        return false;
    };
    Caixa.prototype.geraCodigoDeBarrasPara = function (boleto) {
        var beneficiario = boleto.getBeneficiario();
        var carteira = beneficiario.getCarteira();
        var contaCorrente = pad(beneficiario.getCodigoBeneficiario(), 6, '0');
        var digitoContaCorrente = pad(beneficiario.getDigitoCodigoBeneficiario(), 1, '0');
        var nossoNumeroFormatado = this.getNossoNumeroFormatado(beneficiario);
        var campoLivre = [];
        if (carteira == '14' || carteira == '24') {
            // Carteira 24 é sem registro e carteira 14 é com registro
            // O número 1 significa com registro e o número 2 sem registro
            campoLivre.push(contaCorrente);
            campoLivre.push(beneficiario.getDigitoCodigoBeneficiario());
            campoLivre.push(nossoNumeroFormatado.substring(2, 5));
            campoLivre.push(nossoNumeroFormatado.substring(0, 1));
            campoLivre.push(nossoNumeroFormatado.substring(5, 8));
            campoLivre.push(nossoNumeroFormatado.substring(1, 2));
            campoLivre.push(nossoNumeroFormatado.substring(8));
            var digito = gerador_de_digito_padrao_1.GeradorDeDigitoPadrao.mod11(campoLivre.join(''), {
                de: [0, 10, 11],
                para: 0
            });
            campoLivre.push(digito);
        }
        else {
            throw new Error("Carteira ".concat(carteira, " n\u00E3o implementada para o banco Caixa"));
        }
        return new codigo_de_barras_builder_1.CodigoDeBarrasBuilder(boleto).comCampoLivre(campoLivre);
    };
    Caixa.prototype.getNumeroFormatadoComDigito = function () {
        return [NUMERO_CAIXA, DIGITO_CAIXA].join('-');
    };
    Caixa.prototype.getCarteiraFormatado = function (beneficiario) {
        return pad(beneficiario.getCarteira(), 2, '0');
    };
    Caixa.prototype.getCarteiraTexto = function (beneficiario) {
        var _aux = {
            1: 'RG',
            14: 'RG',
            2: 'SR',
            24: 'SR'
        };
        return _aux[beneficiario.getCarteira()];
    };
    Caixa.prototype.getCodigoFormatado = function (beneficiario) {
        return pad(beneficiario.getCodigoBeneficiario(), 5, '0');
    };
    Caixa.prototype.getImagem = function () {
        return path.join(__dirname, 'logotipos/caixa-economica-federal.png');
    };
    Caixa.prototype.getNossoNumeroFormatado = function (beneficiario) {
        return [
            pad(beneficiario.getCarteira(), 2, '0'),
            pad(beneficiario.getNossoNumero(), 15, '0')
        ].join('');
    };
    Caixa.prototype.getNossoNumeroECodigoDocumento = function (boleto) {
        var beneficiario = boleto.getBeneficiario();
        return [
            this.getNossoNumeroFormatado(beneficiario),
            beneficiario.getDigitoNossoNumero()
        ].join('-');
    };
    Caixa.prototype.getNumeroFormatado = function () {
        return NUMERO_CAIXA;
    };
    Caixa.prototype.getNome = function () {
        return 'Caixa Econômica Federal S/A';
    };
    Caixa.prototype.getImprimirNome = function () {
        return false;
    };
    Caixa.prototype.getAgenciaECodigoBeneficiario = function (boleto) {
        var beneficiario = boleto.getBeneficiario();
        var codigo = this.getCodigoFormatado(beneficiario);
        var digitoCodigo = beneficiario.getDigitoCodigoBeneficiario();
        if (digitoCodigo) {
            codigo += '-' + digitoCodigo;
        }
        return beneficiario.getAgenciaFormatada() + '/' + codigo;
    };
    Caixa.prototype.novoCaixa = function () {
        return new Caixa();
    };
    return Caixa;
}());
exports.Caixa = Caixa;
//# sourceMappingURL=caixa.js.map