"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cecred = void 0;
var path = __importStar(require("path"));
var string_utils_1 = require("../../utils/string-utils");
var codigo_de_barras_builder_1 = require("../codigo-de-barras-builder");
var pad = string_utils_1.StringUtils.pad;
var insert = string_utils_1.StringUtils.insert;
var NUMERO_CECRED = '085';
var DIGITO_CECRED = '1';
var Cecred = /** @class */ (function () {
    function Cecred() {
    }
    Cecred.prototype.getTitulos = function () {
        return {
            instrucoes: 'Instruções (texto de responsabilidade do beneficiário)',
            nomeDoPagador: 'Pagador',
            especie: 'Moeda',
            quantidade: 'Quantidade',
            valor: 'x Valor',
            moraMulta: '(+) Moras / Multa'
        };
    };
    Cecred.prototype.exibirReciboDoPagadorCompleto = function () {
        return true;
    };
    Cecred.prototype.exibirCampoCip = function () {
        return true;
    };
    Cecred.prototype.geraCodigoDeBarrasPara = function (boleto) {
        var beneficiario = boleto.getBeneficiario();
        var errorMsg = 'Erro ao gerar código de barras,';
        if (!beneficiario.getNumeroConvenio() || beneficiario.getNumeroConvenio().length != 6)
            throw new Error("".concat(errorMsg, " n\u00FAmero conv\u00EAnio da cooperativa n\u00E3o possui 6 d\u00EDgitos: ").concat(beneficiario.getNumeroConvenio()));
        if (!beneficiario.getNossoNumero() || beneficiario.getNossoNumero().length != 17)
            throw new Error("".concat(errorMsg, " nosso n\u00FAmero n\u00E3o possui 17 d\u00EDgitos: ").concat(beneficiario.getNossoNumero()));
        if (!beneficiario.getCarteira() || beneficiario.getCarteira().length != 2)
            throw new Error("".concat(errorMsg, " c\u00F3digo carteira n\u00E3o possui 2 d\u00EDgitos: ").concat(beneficiario.getCarteira()));
        var campoLivre = [];
        campoLivre.push(beneficiario.getNumeroConvenio());
        campoLivre.push(beneficiario.getNossoNumero());
        campoLivre.push(beneficiario.getCarteira().substring(0, 2));
        return new codigo_de_barras_builder_1.CodigoDeBarrasBuilder(boleto).comCampoLivre(campoLivre);
    };
    Cecred.prototype.getNumeroFormatadoComDigito = function () {
        return [NUMERO_CECRED, DIGITO_CECRED].join('-');
    };
    Cecred.prototype.getNumeroFormatado = function () {
        return NUMERO_CECRED;
    };
    Cecred.prototype.getCarteiraFormatado = function (beneficiario) {
        return string_utils_1.StringUtils.pad(beneficiario.getCarteira(), 2, '0');
    };
    Cecred.prototype.getCarteiraTexto = function (beneficiario) {
        return string_utils_1.StringUtils.pad(beneficiario.getCarteira(), 2, '0');
    };
    Cecred.prototype.getCodigoFormatado = function (beneficiario) {
        return string_utils_1.StringUtils.pad(beneficiario.getCodigoBeneficiario(), 7, '0');
    };
    Cecred.prototype.getImagem = function () {
        return path.join(__dirname, 'logotipos/ailos.png');
    };
    Cecred.prototype.getNossoNumeroFormatado = function (beneficiario) {
        return string_utils_1.StringUtils.pad(beneficiario.getNossoNumero(), 11, '0');
    };
    Cecred.prototype.getNossoNumeroECodigoDocumento = function (boleto) {
        var beneficiario = boleto.getBeneficiario();
        var nossoNumero = this.getNossoNumeroFormatado(beneficiario);
        if (beneficiario.getDigitoNossoNumero())
            nossoNumero += "-".concat(beneficiario.getDigitoNossoNumero());
        return nossoNumero;
    };
    Cecred.prototype.getNome = function () {
        return 'Ailos';
    };
    Cecred.prototype.getImprimirNome = function () {
        return false;
    };
    Cecred.prototype.getLocaisDePagamentoPadrao = function () {
        return ['PAGAVEL PREFERENCIALMENTE NAS COOPERATIVAS DO SISTEMA AILOS.', 'APOS VENCIMENTO PAGAR SOMENTE NA COOPERATIVA '];
    };
    Cecred.prototype.getAgenciaECodigoBeneficiario = function (boleto) {
        var beneficiario = boleto.getBeneficiario();
        var digitoCodigo = beneficiario.getDigitoCodigoBeneficiario();
        var codigo = this.getCodigoFormatado(beneficiario);
        if (digitoCodigo)
            codigo += '-' + digitoCodigo;
        var agenciaComDigito = beneficiario.getAgenciaFormatada() + '-' + beneficiario.getDigitoAgencia();
        return agenciaComDigito + '/' + codigo;
    };
    Cecred.prototype.novoCecred = function () {
        return new Cecred();
    };
    return Cecred;
}());
exports.Cecred = Cecred;
//# sourceMappingURL=cecred.js.map