"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Boleto = exports.bancos = exports.especiesDeDocumento = void 0;
var banco_do_brasil_1 = require("./boleto/bancos/banco-do-brasil");
var bradesco_1 = require("./boleto/bancos/bradesco");
var caixa_1 = require("./boleto/bancos/caixa");
var cecred_1 = require("./boleto/bancos/cecred");
var itau_1 = require("./boleto/bancos/itau");
var santander_1 = require("./boleto/bancos/santander");
var sicoob_1 = require("./boleto/bancos/sicoob");
var sicredi_1 = require("./boleto/bancos/sicredi");
var string_utils_1 = require("./utils/string-utils");
var pad = string_utils_1.StringUtils.pad;
exports.especiesDeDocumento = {
    // TODO: Ordenar por ordem alfabética
    DMI: 'Duplicata de Venda Mercantil por Indicação',
    DM: 'Duplicata de Venda Mercantil',
    DSI: 'Duplicata de Prestação de Serviços por Indicação de Comprovante',
    NP: 'Nota Promissória',
    ME: 'Mensalidade Escolar',
    DS: 'Duplicata de Prestação de Serviços Original',
    CT: 'Espécie de Contrato',
    LC: 'Letra de Câmbio',
    CPS: 'Conta de Prestação de Serviços de Profissional Liberal ou Declaração do Profissional',
    EC: 'Encargos Condominiais',
    DD: 'Documento de Dívida',
    CCB: 'Cédula de Crédito Bancário',
    CBI: 'Cédula de Crédito Bancário por Indicação',
    CH: 'Cheque',
    CM: 'Contrato de Mútuo',
    RA: 'Recibo de Aluguel Para Pessoa Jurídica (Contrato Aluguel e Recibo)',
    CD: 'Confissão de Dívida Apenas Para Falência de Declaração do Devedor',
    FS: 'Fatura de Serviço',
    TA: 'Termo de Acordo - Ex. Ação Trabalhista',
    CC: 'Contrato de Câmbio',
    DV: 'Diversos'
};
exports.bancos = {
    'Itau': itau_1.Itau,
    '341': itau_1.Itau,
    'Caixa': caixa_1.Caixa,
    '104': caixa_1.Caixa,
    'Bradesco': bradesco_1.Bradesco,
    '237': bradesco_1.Bradesco,
    'BancoBrasil': banco_do_brasil_1.BancoBrasil,
    '001': banco_do_brasil_1.BancoBrasil,
    'Cecred': cecred_1.Cecred,
    '085': cecred_1.Cecred,
    'Sicoob': sicoob_1.Sicoob,
    '756': sicoob_1.Sicoob,
    'Santander': santander_1.Santander,
    '033': santander_1.Santander,
    'Sicredi': sicredi_1.Sicredi,
    '748': sicredi_1.Sicredi
};
// Baixar depois:
// Logotipo HSBC: http://pt.vector.me/browse/29385/hsbc
// Logotipo UNIBANCO: http://pt.vector.me/browse/27779/unibanco
var DATA_BASE = new Date(1997, 10 - 1, 7);
var Boleto = /** @class */ (function () {
    function Boleto() {
    }
    Boleto.novoBoleto = function () {
        return new Boleto()
            .comEspecieMoeda('R$')
            .comCodigoEspecieMoeda(9)
            .comAceite(false)
            .comEspecieDocumento('DV');
    };
    Boleto.prototype.formatarValor = function (valor) {
        valor = valor.toString().split('.');
        var inteiros = valor[0];
        var decimais = valor.length > 1 ? valor[1] : '00';
        decimais = pad(decimais, 2, '0', 'right').substr(0, 2);
        return pad(inteiros + decimais, 10, '0');
    };
    Boleto.prototype.formatarBRL = function (valor) {
        var zeroAEsquerda = true;
        var i = -1;
        return 'R$ ' + (valor.substr(0, 8).split('').reduce(function (acc, cur) {
            if (cur === '0' && zeroAEsquerda) {
                return acc;
            }
            zeroAEsquerda = false;
            return acc + cur;
        }, '').split('').reduceRight(function (acc, cur) {
            i++;
            return cur + (i !== 0 && i % 3 === 0 ? '.' : '') + acc;
        }, '') || 0) + ',' + valor.substr(8, 2);
    };
    Boleto.prototype.getFatorVencimento = function () {
        var vencimento = this.getDatas().getVencimento();
        var diferencaEmDias = (vencimento.getTime() - DATA_BASE.getTime()) / (1000 * 60 * 60 * 24);
        if (diferencaEmDias > 9999) {
            throw new Error('Data fora do formato aceito');
        }
        return Math.floor(diferencaEmDias).toString();
    };
    Boleto.prototype.comEspecieMoeda = function (_especieMoeda) {
        this['_especieMoeda'] = _especieMoeda;
        return this;
    };
    Boleto.prototype.getEspecieMoeda = function () {
        return this._especieMoeda;
    };
    Boleto.prototype.getCodigoEspecieMoeda = function () {
        return this._codigoEspecieMoeda;
    };
    Boleto.prototype.comCodigoEspecieMoeda = function (_codigoEspecieMoeda) {
        this['_codigoEspecieMoeda'] = _codigoEspecieMoeda.toString();
        return this;
    };
    Boleto.prototype.getAceite = function () {
        return this._aceite;
    };
    Boleto.prototype.getAceiteFormatado = function () {
        return this._aceite ? 'S' : 'N';
    };
    Boleto.prototype.comAceite = function (_aceite) {
        this['_aceite'] = _aceite;
        return this;
    };
    Boleto.prototype.getEspecieDocumento = function () {
        return this._especieDocumento;
    };
    Boleto.prototype.comEspecieDocumento = function (_especieDocumento) {
        this['_especieDocumento'] = _especieDocumento;
        return this;
    };
    Boleto.prototype.getDatas = function () {
        return this._datas;
    };
    Boleto.prototype.comDatas = function (_datas) {
        this['_datas'] = _datas;
        return this;
    };
    Boleto.prototype.getValorFormatado = function () {
        return this.formatarValor(this._valorBoleto);
    };
    Boleto.prototype.getValorFormatadoBRL = function () {
        return this.formatarBRL(this.getValorFormatado());
    };
    Boleto.prototype.getValorBoleto = function () {
        return this._valorBoleto;
    };
    Boleto.prototype.comValorBoleto = function (_valorBoleto) {
        if (_valorBoleto < 0) {
            throw new Error('Valor deve ser maior ou igual a zero');
        }
        if (_valorBoleto > 99999999.99) {
            throw new Error('Valor deve ser menor do que noventa e nove milhoes');
        }
        this['_valorBoleto'] = _valorBoleto;
        return this;
    };
    Boleto.prototype.comValor = function (_valorBoleto) {
        this.comValorBoleto(_valorBoleto);
    };
    Boleto.prototype.getNumeroDoDocumentoFormatado = function () {
        return pad(this._numeroDoDocumento || '', 4, '0');
    };
    Boleto.prototype.getNumeroDoDocumento = function () {
        return this._numeroDoDocumento || '';
    };
    Boleto.prototype.comNumeroDoDocumento = function (_numeroDoDocumento) {
        this['_numeroDoDocumento'] = _numeroDoDocumento;
        return this;
    };
    Boleto.prototype.getInstrucoes = function () {
        return this._instrucoes || [];
    };
    Boleto.prototype.comInstrucoes = function (_instrucoes) {
        if (arguments.length > 1) {
            _instrucoes = Array.prototype.slice.call(arguments, 0);
        }
        if (typeof _instrucoes === 'string') {
            _instrucoes = [_instrucoes];
        }
        if (_instrucoes.length > 5) {
            throw new Error('Máximo de cinco instruções permitidas');
        }
        this['_instrucoes'] = _instrucoes;
        return this;
    };
    Boleto.prototype.getDescricoes = function () {
        return this._descricoes || [];
    };
    Boleto.prototype.comDescricoes = function (_descricoes) {
        if (arguments.length > 1) {
            _descricoes = Array.prototype.slice.call(arguments, 0);
        }
        if (typeof _descricoes === 'string') {
            _descricoes = [_descricoes];
        }
        if (_descricoes.length > 5) {
            throw new Error('Máximo de cinco instruções permitidas');
        }
        this['_descricoes'] = _descricoes;
        return this;
    };
    Boleto.prototype.getLocaisDePagamento = function () {
        if (this._locaisDePagamento)
            return this._locaisDePagamento;
        if (this.getBanco().getLocaisDePagamentoPadrao)
            return this.getBanco().getLocaisDePagamentoPadrao();
        return [];
    };
    Boleto.prototype.comLocaisDePagamento = function (_locaisDePagamento) {
        if (arguments.length > 1) {
            _locaisDePagamento = Array.prototype.slice.call(arguments, 0);
        }
        if (typeof _locaisDePagamento === 'string') {
            _locaisDePagamento = [_locaisDePagamento];
        }
        if (_locaisDePagamento.length > 2) {
            throw new Error('Máximo de dois locais de pagamento permitidos');
        }
        this['_locaisDePagamento'] = _locaisDePagamento;
        return this;
    };
    Boleto.prototype.getQuantidadeDeMoeda = function () {
        return this._quantidadeDeMoeda;
    };
    Boleto.prototype.comQuantidadeDeMoeda = function (_quantidadeDeMoeda) {
        this['_quantidadeDeMoeda'] = _quantidadeDeMoeda;
        return this;
    };
    Boleto.prototype.getBanco = function () {
        return this._banco;
    };
    Boleto.prototype.comBanco = function (_banco) {
        this['_banco'] = _banco;
        return this;
    };
    Boleto.prototype.getPagador = function () {
        return this._pagador;
    };
    Boleto.prototype.comPagador = function (_pagador) {
        this['_pagador'] = _pagador;
        return this;
    };
    Boleto.prototype.getBeneficiario = function () {
        return this._beneficiario;
    };
    Boleto.prototype.comBeneficiario = function (_beneficiario) {
        this['_beneficiario'] = _beneficiario;
        return this;
    };
    Boleto.prototype.getValorDescontosFormatadoBRL = function () {
        if (!this.getValorDescontos()) {
            return '';
        }
        return this.formatarBRL(this.formatarValor(this.getValorDescontos()));
    };
    Boleto.prototype.getValorDescontos = function () {
        return this._valorDescontos || 0;
    };
    Boleto.prototype.comValorDescontos = function (_valorDescontos) {
        this['_valorDescontos'] = _valorDescontos;
        return this;
    };
    Boleto.prototype.getValorDeducoesFormatadoBRL = function () {
        if (!this.getValorDeducoes()) {
            return '';
        }
        return this.formatarBRL(this.formatarValor(this.getValorDeducoes()));
    };
    Boleto.prototype.getValorDeducoes = function () {
        return this._valorDeducoes || 0;
    };
    Boleto.prototype.comValorDeducoes = function (_valorDeducoes) {
        this['_valorDeducoes'] = _valorDeducoes;
        return this;
    };
    Boleto.prototype.getValorMultaFormatadoBRL = function () {
        return this.formatarBRL(this.formatarValor(this.getValorMulta()));
    };
    Boleto.prototype.getValorMulta = function () {
        return this._valorMulta || 0;
    };
    Boleto.prototype.comValorMulta = function (_valorMulta) {
        this['_valorMulta'] = _valorMulta;
        return this;
    };
    Boleto.prototype.getValorAcrescimosFormatadoBRL = function () {
        return this.this.formatarBRL(this.this.formatarValor(this.getValorAcrescimos()));
    };
    Boleto.prototype.getValorAcrescimos = function () {
        return this._valorAcrescimos || 0;
    };
    Boleto.prototype.comValorAcrescimos = function (_valorAcrescimos) {
        this['_valorAcrescimos'] = _valorAcrescimos;
        return this;
    };
    return Boleto;
}());
exports.Boleto = Boleto;
//# sourceMappingURL=boletoUtils.js.map