"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.YamlLine = void 0;
var yaml = __importStar(require("js-yaml"));
var fs = __importStar(require("fs"));
var moment_1 = __importDefault(require("moment"));
var regexPicture = function (exp, picture) {
    var regex = new RegExp(exp);
    var out = [];
    var text = picture; // "9(10)V9(10)"
    var result = regex.exec(text);
    while (result) {
        out.push(result[1]);
        result = regex.exec(text);
    }
    return out;
};
/*
 * Alfanumérico (picture X): alinhados à esquerda com brancos à direita. Preferencialmente,
 * todos os caracteres devem ser maiúsculos. Aconselhase a não utilização de
 * caracteres especiais (ex.: “Ç”, “?”,, etc) e
 * acentuação gráfica (ex.: “Á”, “É”, “Ê”, etc) e os campos não utiliza dos deverão ser preenchidos com brancos.
 * */
var formatText = function (value, size) {
    value = value.replace(/[^a-zA-Z0-9 ]/g, '').substr(0, size);
    while (value.length < size) {
        value = value + ' ';
    }
    return value;
};
/*  Numérico (picture 9): alinhado à direita com zeros à esquerda e os campos não utilizados deverão ser preenchidos
* com zeros. - Vírgula assumida (picture V): indica a posição da vírgula dentro de um campo numérico.
* Exemplo: num campo com picture “9(5)V9(2)”, o número “876,54” será representado por “0087654”
* @param {*} picture
* @param {*} value
*/
var formatNumber = function (value, size) {
    if (value != undefined)
        value = value.replace(/[^0-9]/g, '');
    while (value.length < size) {
        value = '0' + value;
    }
    return value;
};
var formatDate = function (value, size, dateformat) {
    // if(!value){
    //   return new Date()
    // }
    // value = value.replace(/[^0-9]/g, "")
    while (value.length < size) {
        value = '0' + value;
    }
    // date_format: '%d%m%y'
    return value;
};
var formatCurrency = function (value, number, decimal) {
    if (!value) {
        value = '';
    }
    value += '';
    value = value.replace(/[.R$]/g, '');
    var vals = [];
    vals.push(value.slice(0, -decimal));
    vals.push(value.slice(-decimal));
    if (vals.length === 1) {
        vals[1] = '';
    }
    while (vals[0].length < number) {
        vals[0] = '0' + vals[0];
    }
    while (vals[1].length < decimal) {
        vals[1] = '0' + vals[1];
    }
    return vals[0] + vals[1];
};
var YamlLine = /** @class */ (function () {
    function YamlLine() {
    }
    YamlLine.makeLine = function (layout, data) {
        var line = '';
        var object = {};
        if (layout) {
            Object.keys(layout).forEach(function (key) {
                var item = layout[key];
                var value;
                if (key in data && data[key]) {
                    value = data[key];
                }
                else {
                    value = item.default;
                }
                var baseValue = value ? value + '' : '';
                var pictures = YamlLine.usePicture(item, baseValue);
                object[key] = pictures;
                line += pictures;
            });
        }
        return { line: line, object: object };
    };
    YamlLine.readLine = function (layout, data) {
        var object = {};
        if (layout) {
            Object.keys(layout).forEach(function (key) {
                var item = layout[key];
                if (item.pos) {
                    object[key] = YamlLine.extractDataFromPicture(item, data);
                }
                else {
                    console.warn('Nao tem posicao pra key', key);
                }
            });
        }
        return object;
    };
    YamlLine.extractDataFromPicture = function (item, value, ignoreDefault) {
        if (ignoreDefault === void 0) { ignoreDefault = false; }
        var start = item.pos[0] - 1; // yml começa no 1 e array em 0
        var length = item.pos[1] - item.pos[0] + 1;
        var timeZone = 'America/Sao_Paulo';
        if (value) {
            value = value.substr(start, length) || (ignoreDefault ? null : item.default);
            var picture = item.picture;
            if (picture.indexOf('V9') > 0) {
                var out = regexPicture(/9\((\w+?)\)/g, picture);
                return parseFloat("".concat(value.substr(0, out[0]), ".").concat(value.substr(out[0], out[1])));
            }
            else if (picture.startsWith('9')) {
                // const out = regexPicture(/9\((\w+?)\)/g, picture);
                if (item.date_format) {
                    return (0, moment_1.default)(value, item.date_format).endOf('day').tz(timeZone).toDate();
                }
                else {
                    return parseInt(value, 10);
                }
            }
            else if (picture.startsWith('X')) {
                return value.trim();
            }
            else {
                throw new Error("Cant recognize picture for ".concat(picture));
            }
        }
        else {
            return null;
        }
    };
    YamlLine.readYaml = function (filename) {
        try {
            return yaml.safeLoad(fs.readFileSync(filename, "utf8"));
        }
        catch (e) {
            console.log(e);
            return null;
        }
    };
    YamlLine.usePicture = function (item, value) {
        if (value === void 0) { value = ''; }
        var picture = item.picture;
        if (picture.indexOf('V9') > 0) {
            var out = regexPicture(/9\((\w+?)\)/g, picture);
            return formatCurrency(value, out[0], out[1]);
        }
        else if (picture.startsWith('9')) {
            var out = regexPicture(/9\((\w+?)\)/g, picture);
            if (item.date_format) {
                return formatDate(value, out[0], item.date_format);
            }
            else {
                return formatNumber(value, parseInt(out[0], 10));
            }
        }
        else if (picture.startsWith('X')) {
            var out = regexPicture(/X\((\w+?)\)/g, picture);
            return formatText(value, out[0]);
        }
        else {
            throw new Error("Cant recognize picture for ".concat(picture));
        }
    };
    return YamlLine;
}());
exports.YamlLine = YamlLine;
//# sourceMappingURL=yaml.line.js.map